Base views
----------

|cubicweb| provides a lot of standard views, that can be found in
:mod:`cubicweb.web.views` sub-modules.

A certain number of views are used to build the web interface, which apply to one
or more entities. As other appobjects, their identifier is what distinguish them
from each others. The most generic ones, found in
:mod:`cubicweb.web.views.baseviews`, are described below.

You'll probably want to customize one or more of the described views which are
default, generic, implementations.


.. automodule:: cubicweb.web.views.baseviews

You will also find modules providing some specific services:

.. automodule:: cubicweb.web.views.navigation

